#
# spec file for package dustrac
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dustrac
Version:        1.12.0
Release:        1.5
Summary:        Tile-based 2D Racing Game
License:        GPL-3.0 and CC-BY-SA-3.0
Group:          Amusements/Games/Action/Race
Url:            https://github.com/juzzlin/DustRacing2D
Source:         https://github.com/juzzlin/DustRacing2D/releases/download/%{version}/dustrac-%{version}.tar.gz
BuildRequires:  cmake >= 2.8.7
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc >= 4.6
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkg-config
BuildRequires:  ubuntu-fonts
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(vorbisfile)
Requires:       ubuntu-fonts
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Dust Racing is a tile-based 2D racing game written with Qt (in C++)
and OpenGL. Dust Racing comes with a Qt-based level editor for level
creation. A separate engine, MiniCore, is used for physics modeling.

%prep
%setup -q

%build
export CXXFLAGS="%{optflags}"
./configure -DReleaseBuild=1 -DCMAKE_INSTALL_PREFIX=%{_prefix} -DDATA_PATH=%{_datadir}/%{name} -DDOC_PATH=%{_datadir}/doc/packages/%{name} -DUseQt5=%{qt5}
make %{?_smp_mflags} VERBOSE=1

%install
make DESTDIR=%{buildroot} install
%fdupes -s %{buildroot}
desktop-file-edit --set-generic-name="2D Racing Game" --remove-key Categories \
                  --add-category=Game --add-category=ArcadeGame \
                  --set-key=Exec --set-value=dustrac-game \
                  %{buildroot}%{_datadir}/applications/dustrac-game.desktop
desktop-file-edit --set-generic-name="Racing Track Editor" --remove-key Categories \
                  --add-category=Game --add-category=ArcadeGame \
                  --set-key=Exec --set-value=dustrac-editor \
                  %{buildroot}%{_datadir}/applications/dustrac-editor.desktop

# Use system fonts
rm %{buildroot}%{_datadir}/%{name}/fonts/UbuntuMono-B.ttf
ln -s %{_datadir}/fonts/truetype/UbuntuMono-B.ttf %{buildroot}%{_datadir}/%{name}/fonts/UbuntuMono-B.ttf
rm %{buildroot}%{_datadir}/%{name}/fonts/UbuntuMono-R.ttf
ln -s %{_datadir}/fonts/truetype/UbuntuMono-R.ttf %{buildroot}%{_datadir}/%{name}/fonts/UbuntuMono-R.ttf

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%{_datadir}/doc/packages/%{name}
%{_bindir}/dustrac-game
%{_bindir}/dustrac-editor
%{_datadir}/%{name}/
%{_datadir}/%{name}/images
%{_datadir}/%{name}/levels
%{_datadir}/applications/dustrac-game.desktop
%{_datadir}/applications/dustrac-editor.desktop
%{_datadir}/pixmaps/dustrac-game.png
%{_datadir}/pixmaps/dustrac-editor.png
%{_datadir}/icons/hicolor/64x64/apps/dustrac-game.png
%{_datadir}/icons/hicolor/64x64/apps/dustrac-editor.png
%dir %{_datadir}/appdata/
%{_datadir}/appdata/dustrac.appdata.xml

%changelog
* Sat Dec 24 2016 mailaender@opensuse.org
- Drop appdata.patch (included upstream)
- Update to version 1.12.0
  * 7 new tracks by Wuzzy
  * Add German translation
  * Make the steering more stable
  * Redo startlight graphics in SVG
  * Improve log messages about translations.
  * Editor: Improve override cursor logic.
  * Editor: Remove dead code.
  * Update Czech translations.
  * Fix GitHub issue #7: Bad track preview images.
  * Fix GitHub issue #6: Assertion failure when empty route cleared.
  * Remove lower bridge rails for now.
  * CMake: Switch to the recommended way to link Qt5
* Mon Aug 22 2016 mailaender@opensuse.org
- Add an appdata.xml file.
* Sat Jul 30 2016 jengelh@inai.de
- Update description
* Sat Jul 30 2016 mailaender@opensuse.org
- fix license
- use system fonts
* Fri May  1 2015 mailaender@opensuse.org
- update to 1.11.0
* Sat Apr 11 2015 mailaender@opensuse.org
- update to 1.10.0
* Sat Jan 24 2015 mailaender@opensuse.org
- update to 1.9.2
* Thu Jan  1 2015 mailaender@opensuse.org
- update to 1.9.1
* Tue Dec 30 2014 mailaender@opensuse.org
- update to 1.8.3
* Thu Nov  6 2014 mailaender@opensuse.org
- update to 1.8.0
* Sat Oct  4 2014 mailaender@opensuse.org
- update to 1.7.3
- build with Qt5 where available
* Wed Apr 16 2014 mailaender@opensuse.org
- update to 1.7.2
- added %%post macros for .desktop file and icons
* Sun Mar  9 2014 mailaender@opensuse.org
- update to 1.7.1
* Sun Feb 16 2014 mailaender@opensuse.org
- update to 1.6.3
* Thu Dec 26 2013 mailaender@opensuse.org
- update to 1.6.2
* Sun Dec  1 2013 mailaender@opensuse.org
- Adjusted build dependencies of vorbisfile and glu to match better.
* Sun Dec  1 2013 mailaender@opensuse.org
- Update to version 1.5.2
* Thu Oct  3 2013 mailaender@opensuse.org
- Update to version 1.4.6
* Sat Sep 14 2013 mailaender@opensuse.org
- Update to version 1.4.5
- Adhere to https://en.opensuse.org/SourceUrls
* Wed Dec 19 2012 joop.boonen@opensuse.org
- Added BuildRequires: glu-devel as it's not a BuildRequirement
  for Mesa-devel anymore for openSUSE > 12.2
* Tue Sep  4 2012 mailaender@opensuse.org
- Update to version 0.7.3
  - FHS compatible installation patch is now in upstream
* Thu Aug 30 2012 pth@suse.de
- Replace the use of suse_update_desktop_file by calling
  desktop-edit-file.
* Wed Aug 29 2012 pth@suse.de
- ADD RPM_OPT_FLAGS to options passed to compiler.
- Modify the exec entry in the .desktop files.
* Wed Aug 29 2012 pth@suse.de
- Initial package for openSUSE
- Install binaries in /usr/bin and data in /usr/share/games/DustRacing
